@@ -145,6 +145,11 @@ sub set_zfs_property {
     close ZFS_SET_PIPE;
 }
 
+
+=head1 SEE ALSO
+
+The L<FreeBSD documentation on ZFS|https://www.freebsd.org/doc/handbook/zfs.html>.
+
 =head1 AUTHOR
 
 Patrice Clement <monsieurp at cpan.org>
