@@ -183,7 +183,7 @@ sub show_help {
     return if !defined $selected;
     chomp $selected;
 
-    return if $selected =~ m/^PROPERTY/;
+    return if $selected =~ m/^(PROPERTY|no datasets available)/;
 
     my ( $property, undef, undef ) = split /\s+/, $selected;
     my $help_message = $text->help_messages()->{$property};
@@ -474,6 +474,10 @@ sub onpress_back_to_properties_list {
     draw_dataset_properties_screen($current_dataset);
 }
 
+=head1 SEE ALSO
+
+The L<Curses::UI> Perl module.
+
 =head1 AUTHOR
 
 Patrice Clement <monsieurp at cpan.org>
